@@ -14,6 +14,7 @@ from pubtools.pulplib import (
     RpmUnit,
 )
 
+from pubtools._pulp.arguments import SplitAndExtend
 from pubtools._pulp.services import (
     CollectorService,
     PulpClientService,
@@ -28,6 +29,13 @@ step = PulpTask.step
 LOG = logging.getLogger("pubtools.pulp")
 
 
+# Due to some false positives such as:
+# E1101: Instance of 'CollectorProxy' has no 'search_repository' member (no-member)
+# Confused by multiple inheritance in the Service classes?
+#
+# pylint: disable=no-member
+
+
 @attr.s
 class ClearedRepo(object):
     """Represents a single repo which has been cleared."""
@@ -51,10 +59,9 @@ class ClearRepo(
 
     @property
     def content_type(self):
-        type_strs = (self.args.content_type or "").split(",")
         # Only return non-None if there were really any types given.
         # Otherwise, return None to let library defaults apply
-        return [x for x in type_strs if x] or None
+        return self.args.content_type or None
 
     def add_args(self):
         super(ClearRepo, self).add_args()
@@ -66,6 +73,8 @@ class ClearRepo(
             "--content-type",
             help="remove only content of these comma-separated type(s)",
             type=str,
+            action=SplitAndExtend,
+            split_on=",",
         )
         self.parser.add_argument("repo", nargs="+", help="Repositories to be cleared")
 
